
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#if !defined(_ADWAITA_INSIDE) && !defined(ADWAITA_COMPILATION)
#error "Only <adwaita.h> can be included directly."
#endif

#include "adw-version.h"

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "adw-flap.h" */

ADW_AVAILABLE_IN_ALL GType adw_flap_fold_policy_get_type (void);
#define ADW_TYPE_FLAP_FOLD_POLICY (adw_flap_fold_policy_get_type ())

ADW_AVAILABLE_IN_ALL GType adw_flap_transition_type_get_type (void);
#define ADW_TYPE_FLAP_TRANSITION_TYPE (adw_flap_transition_type_get_type ())

/* enumerations from "adw-fold-threshold-policy.h" */

ADW_AVAILABLE_IN_ALL GType adw_fold_threshold_policy_get_type (void);
#define ADW_TYPE_FOLD_THRESHOLD_POLICY (adw_fold_threshold_policy_get_type ())

/* enumerations from "adw-header-bar.h" */

ADW_AVAILABLE_IN_ALL GType adw_centering_policy_get_type (void);
#define ADW_TYPE_CENTERING_POLICY (adw_centering_policy_get_type ())

/* enumerations from "adw-leaflet.h" */

ADW_AVAILABLE_IN_ALL GType adw_leaflet_transition_type_get_type (void);
#define ADW_TYPE_LEAFLET_TRANSITION_TYPE (adw_leaflet_transition_type_get_type ())

/* enumerations from "adw-navigation-direction.h" */

ADW_AVAILABLE_IN_ALL GType adw_navigation_direction_get_type (void);
#define ADW_TYPE_NAVIGATION_DIRECTION (adw_navigation_direction_get_type ())

/* enumerations from "adw-squeezer.h" */

ADW_AVAILABLE_IN_ALL GType adw_squeezer_transition_type_get_type (void);
#define ADW_TYPE_SQUEEZER_TRANSITION_TYPE (adw_squeezer_transition_type_get_type ())

/* enumerations from "adw-view-switcher.h" */

ADW_AVAILABLE_IN_ALL GType adw_view_switcher_policy_get_type (void);
#define ADW_TYPE_VIEW_SWITCHER_POLICY (adw_view_switcher_policy_get_type ())
G_END_DECLS

/* Generated data ends here */

